==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/installer/messages/zh-CN/base.php <==
<?php

return [
    '<strong>Admin</strong> Account' => '<strong>管理员</strong> 帐户',
    '<strong>Configuration</strong>' => '<strong>配置</strong>',
    '<strong>Congratulations</strong>. You\'re done.' => '<strong>祝贺你</strong>， 安装完成。',
    '<strong>Database</strong> Configuration' => '<strong>数据库</strong> 配置',
    '<strong>Example</strong> contents' => '<strong>示例</strong> 内容',
    '<strong>System</strong> Check' => '<strong>系统</strong> 检测',
    '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>欢迎来到</strong> HumHub<br>你的社交网络工具箱！',
    'Allow access for non-registered users to public content (guest access)' => '允许非注册用户访问公开内容（访客访问）',
    'Allow friendships between members' => '允许成员之间',
    'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => '下面你必须输入数据库连接的详细信息。如果你不确定，请与系统管理员联系',
    'Calvin Klein – Between love and madness lies obsession.' => '卡尔文 - 痴迷于爱和疯狂之间的谎言。',
    'Check again' => '重新检测',
    'Congratulations! Everything is ok and ready to start over!' => '祝贺你!一切准备就绪！',
    'Create Admin Account' => '创建管理员账户',
    'Downloading & Installing Modules...' => '下载安装模块...',
    'External users can register (show registration form on login)' => '外部用户可以注册（注册表单将显示在登录页）',
    'Here you can decide how new, unregistered users can access HumHub.' => '在这里你可以决是否允许定新的，未注册的用户访问HumHub。',
    'Hostname' => '主机名',
    'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'MySQL数据库服务器的主机名（例如:如果MySQL是同一台机器上运行,输入localhost）',
    'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub是非常灵活的，可以通过安装各种不同的应用模块来调整/或扩大功能。下面推荐几个我们认为重要的模块给你。当然，你也可以稍后在管理区域中安装更多模块。',
    'I want to use HumHub for:' => '我想用HumHub来：',
    'Initializing database...' => '初始化数据库...',
    'My club' => '我的俱乐部',
    'My community' => '我的社区',
    'My company (Social Intranet / Project management)' => '我的公司（社会网络/项目管理）',
    'My educational institution (school, university)' => '我的教育机构（学校，大学）',
    'Name of Database' => '数据库名',
    'Name of your network' => '你的网络名称',
    'Newly registered users have to be activated by an admin first' => '新注册的用户必须由管理员激活',
    'Next' => '下一步',
    'Nike – Just buy it. :wink:' => '耐克 - 夹斯特杜伊特。',
    'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => '当然，你的新的社交平台需要一个名字。请将默认名称更改为您喜欢的。（例如，你的公司，组织或俱乐部的名称）',
    'Ohh, something went wrong!' => '糟糕, 出错了！',
    'Password' => '密码',
    'Port' => '端口',
    'Recommended <strong>Modules</strong>' => '推荐 <strong>模块',
    'Registered members can invite new users via email' => '注册会员可以通过电子邮件邀请新用户',
    'Security <strong>Settings</strong>' => '安全 <strong>设置</strong>',
    'Set up example content (recommended)' => '设置示例内容（推荐）',
    'Sign in' => '登录',
    'Skip this step, I want to set up everything manually' => '跳过这一步，我想手动设置一切',
    'Social Network <strong>Name</strong>' => '社交网络 <strong>名字</strong>',
    'The installation completed successfully! Have fun with your new social network.' => '安装成功完成！祝你在新社交平台上玩得开心。',
    'The name of the database you want to run HumHub in.' => '你想要存humhub数据的数据库名',
    'This overview shows all system requirements of HumHub.' => '以下展示了humhub的所有系统需求',
    'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => '该向导将安装和配置你自己的humhub实例.<br><br>点击下一步继续。',
    'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => '为了避免初始登录后空白的仪表板，humhub可以安装一些示例内容。这将给你一个很好humhub概览。您可以随时删除示例内容。',
    'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => '为了简化配置，我们预定义了几个最常见的用例，采用了不同的选项模块和设置。你可以在稍后调整他们。',
    'Username' => '用户名',
    'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => '我们正在寻找伟大的口号。你能拿出一些样品吗？',
    'Welcome Space' => '欢迎空间',
    'Yay! I\'ve just installed HumHub :sunglasses:' => '太棒了，我刚刚安装了HumHub',
    'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => '你几乎完成了安装。在这一步中，您必须填写表单，以创建一个管理帐户。有了这个帐户，你可以管理整个平台。',
    'Your MySQL password.' => '数据库存密码。',
    'Your MySQL username' => '数据库用户名',
    'Your first sample space to discover the platform.' => '你的第一个样本空间发现平台。',
    '<strong>Pretty URLs</strong> configuration' => '',
    '<strong>Scheduled jobs</strong>' => '',
    'Add following the lines to the crontab:' => '',
    'Create the database if it doesn\'t exist yet.' => '',
    'Default Language' => '',
    'Default Timezone' => '',
    'HumHub uses cron jobs to execute scheduled or to run potentially heavy tasks such as sending out email summaries and notifications or optimizing the search index.' => '',
    'In order to activate this feature, it is necessary to edit the HumHub configuration and, potentially, the configuration of the WebServer.' => '',
    'Installation Example:' => '',
    'Language and timezone are automatically set according to the user\'s browser settings. If that is not possible, the default settings are used.' => '',
    'Localisation' => '',
    'On HumHub\'s side, you will need to edit the configuration file <code>{configFile}</code> and add the following block:' => '',
    'Open the crontab of HumHub/PHP process user e.g. <code>{user}</code>.' => '',
    'Optional: Port of your MySQL Database Server. Leave empty to use default port.' => '',
    'Our documentation provides a more detailed look into <a href="{link}" target="_blank">Pretty URLs</a>.' => '',
    'Per default, the HumHub URL includes an <code>index.php</code> file in the address, resulting in a URL that looks like "<a>https://example.com/index.php?r=dashboard%2Fdashboard</a>" for example. By using the Pretty URL or URL Rewriting feature, it is possible to create shorter and easier to understand URLs, such as "<a>https://example.com/dashboard</a>".' => '',
    'Registered members can invite new users via link' => '',
    'This topic is covered in more detail in our <a href="{link}" target="_blank">documentation</a>. If you have trouble setting up the job scheduling described in the documentation, please contact your server administrator for support.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/installer/messages/zh-CN/base.php <==
<?php

return [
    '<strong>Admin</strong> Account' => '<strong>管理员</strong> 帐户',
    '<strong>Configuration</strong>' => '<strong>配置</strong>',
    '<strong>Congratulations</strong>. You\'re done.' => '<strong>祝贺你</strong>， 安装完成。',
    '<strong>Database</strong> Configuration' => '<strong>数据库</strong> 配置',
    '<strong>Example</strong> contents' => '<strong>示例</strong> 内容',
    '<strong>System</strong> Check' => '<strong>系统</strong> 检测',
    '<strong>Welcome</strong> to HumHub<br>Your Social Network Toolbox' => '<strong>欢迎来到</strong> HumHub<br>你的社交网络工具箱！',
    'Allow access for non-registered users to public content (guest access)' => '允许非注册用户访问公开内容（访客访问）',
    'Allow friendships between members' => '允许成员之间',
    'Below you have to enter your database connection details. If you’re not sure about these, please contact your system administrator.' => '下面你必须输入数据库连接的详细信息。如果你不确定，请与系统管理员联系',
    'Calvin Klein – Between love and madness lies obsession.' => '卡尔文 - 痴迷于爱和疯狂之间的谎言。',
    'Check again' => '重新检测',
    'Congratulations! Everything is ok and ready to start over!' => '祝贺你!一切准备就绪！',
    'Create Admin Account' => '创建管理员账户',
    'Downloading & Installing Modules...' => '下载安装模块...',
    'External users can register (show registration form on login)' => '外部用户可以注册（注册表单将显示在登录页）',
    'Here you can decide how new, unregistered users can access HumHub.' => '在这里你可以决是否允许定新的，未注册的用户访问HumHub。',
    'Hostname' => '主机名',
    'Hostname of your MySQL Database Server (e.g. localhost if MySQL is running on the same machine)' => 'MySQL数据库服务器的主机名（例如:如果MySQL是同一台机器上运行,输入localhost）',
    'HumHub is very flexible and can be adjusted and/or expanded for various different applications thanks to its’ different modules.  The following modules are just a few examples and the ones we thought are most important for your chosen application.<br><br>You can always install or remove modules later. You can find more available modules after installation in the admin area.' => 'HumHub是非常灵活的，可以通过安装各种不同的应用模块来调整/或扩大功能。下面推荐几个我们认为重要的模块给你。当然，你也可以稍后在管理区域中安装更多模块。',
    'I want to use HumHub for:' => '我想用HumHub来：',
    'Initializing database...' => '初始化数据库...',
    'My club' => '我的俱乐部',
    'My community' => '我的社区',
    'My company (Social Intranet / Project management)' => '我的公司（社会网络/项目管理）',
    'My educational institution (school, university)' => '我的教育机构（学校，大学）',
    'Name of Database' => '数据库名',
    'Name of your network' => '你的网络名称',
    'Newly registered users have to be activated by an admin first' => '新注册的用户必须由管理员激活',
    'Next' => '下一步',
    'Nike – Just buy it. :wink:' => '耐克 - 夹斯特杜伊特。',
    'Of course, your new social network needs a name. Please change the default name with one you like. (For example the name of your company, organization or club)' => '当然，你的新的社交平台需要一个名字。请将默认名称更改为您喜欢的。（例如，你的公司，组织或俱乐部的名称）',
    'Ohh, something went wrong!' => '糟糕, 出错了！',
    'Password' => '密码',
    'Port' => '端口',
    'Recommended <strong>Modules</strong>' => '推荐 <strong>模块',
    'Registered members can invite new users via email' => '注册会员可以通过电子邮件邀请新用户',
    'Security <strong>Settings</strong>' => '安全 <strong>设置</strong>',
    'Set up example content (recommended)' => '设置示例内容（推荐）',
    'Sign in' => '登录',
    'Skip this step, I want to set up everything manually' => '跳过这一步，我想手动设置一切',
    'Social Network <strong>Name</strong>' => '社交网络 <strong>名字</strong>',
    'The installation completed successfully! Have fun with your new social network.' => '安装成功完成！祝你在新社交平台上玩得开心。',
    'The name of the database you want to run HumHub in.' => '你想要存humhub数据的数据库名',
    'This overview shows all system requirements of HumHub.' => '以下展示了humhub的所有系统需求',
    'This wizard will install and configure your own HumHub instance.<br><br>To continue, click Next.' => '该向导将安装和配置你自己的humhub实例.<br><br>点击下一步继续。',
    'To avoid a blank dashboard after your initial login, HumHub can install example contents for you. Those will give you a nice general view of how HumHub works. You can always delete the individual contents.' => '为了避免初始登录后空白的仪表板，humhub可以安装一些示例内容。这将给你一个很好humhub概览。您可以随时删除示例内容。',
    'To simplify the configuration, we have predefined setups for the most common use cases with different options for modules and settings. You can adjust them during the next step.' => '为了简化配置，我们预定义了几个最常见的用例，采用了不同的选项模块和设置。你可以在稍后调整他们。',
    'Username' => '用户名',
    'We\'re looking for great slogans of famous brands. Maybe you can come up with some samples?' => '我们正在寻找伟大的口号。你能拿出一些样品吗？',
    'Welcome Space' => '欢迎空间',
    'Yay! I\'ve just installed HumHub :sunglasses:' => '太棒了，我刚刚安装了HumHub',
    'You\'re almost done. In this step you have to fill out the form to create an admin account. With this account you can manage the whole network.' => '你几乎完成了安装。在这一步中，您必须填写表单，以创建一个管理帐户。有了这个帐户，你可以管理整个平台。',
    'Your MySQL password.' => '数据库存密码。',
    'Your MySQL username' => '数据库用户名',
    'Your first sample space to discover the platform.' => '你的第一个样本空间发现平台。',
    '<strong>Apache</strong> web server detected.' => '',
    '<strong>Nginx</strong> web server detected.' => '',
    '<strong>Pretty URLs</strong>' => '',
    '<strong>Scheduled jobs</strong>' => '',
    'Add following the lines to the crontab:' => '',
    'Create the database if it doesn\'t exist yet.' => '',
    'Default Language' => '',
    'Default Timezone' => '',
    'Ensure the following rule is present in your configuration: <strong>try_files $uri $uri/ /index.php?$args;</strong>.' => '',
    'For more information on this topic, please refer to our <a href="{link}" target="_blank">documentation</a>.' => '',
    'HumHub uses cron jobs to execute scheduled or to run potentially heavy tasks such as sending out email summaries and notifications or optimizing the search index.' => '',
    'In the installation folder, locate the <strong>.env.example</strong> file and copy its contents into the <strong>.env</strong> file. Next, find the <strong>Pretty URLs</strong> block and uncomment it by removing the <strong>#</strong> symbol.' => '',
    'Installation Example:' => '',
    'Language and timezone are automatically set according to the user\'s browser settings. If that is not possible, the default settings are used.' => '',
    'Localisation' => '',
    'Make sure that the following file is writable: thi' => '',
    'Open the crontab of HumHub/PHP process user e.g. <code>{user}</code>.' => '',
    'Optional: Port of your MySQL Database Server. Leave empty to use default port.' => '',
    'Pretty URLs may not work correctly.' => '',
    'Pretty URLs should work correctly.' => '',
    'Registered members can invite new users via link' => '',
    'The <strong>.htaccess</strong> file is in place.' => '',
    'The <strong>.htaccess</strong> file is not in place. In the installation folder, locate the <strong>.htaccess.dist</strong> file and rename it to <strong>.htaccess</strong>.' => '',
    'The <strong>mod_rewrite</strong> module is active.' => '',
    'The <strong>mod_rewrite</strong> module is not enabled.' => '',
    'This topic is covered in more detail in our <a href="{link}" target="_blank">documentation</a>. If you have trouble setting up the job scheduling described in the documentation, please contact your server administrator for support.' => '',
    'Unable to automatically detect your web server type. Please ensure URL rewriting is configured.' => '',
];
